#
# spec file for package gegl-unstable
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define debug_package_requires libgegl-0_3-0 = %{version}-%{release}
Name:           gegl-unstable
%define _name gegl
Version:        0.3.6
Release:        3.1
Summary:        Generic Graphics Library
License:        GPL-3.0+ and LGPL-3.0+
Group:          System/Libraries
Url:            http://gegl.org/
Source:         %{_name}-%{version}.tar.xz
BuildRequires:  ImageMagick
BuildRequires:  OpenEXR-devel
BuildRequires:  SDL-devel
BuildRequires:  asciidoc
BuildRequires:  babl-devel >= 0.1.14
BuildRequires:  enscript
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig(json-glib-1.0)
# multiple provides by gd and gd-tools
BuildRequires:  gd
BuildRequires:  glib2-devel >= 2.16.1
BuildRequires:  graphviz-gd
# Only for directory ownership:
BuildRequires:  gtk-doc
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  lensfun-devel
# Needed to build the doc, as Bitstream Vera Sans is the referenced font.
BuildRequires:  liberation-fonts
BuildRequires:  libexiv2-devel
BuildRequires:  libjasper-devel >= 1.900.1
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  librsvg-devel
BuildRequires:  libspiro-devel
BuildRequires:  libstdc++-devel
BuildRequires:  lua-devel
BuildRequires:  ruby
BuildRequires:  pkgconfig(gexiv2)
BuildRequires:  pkgconfig(libavcodec) >= 55.69.100
BuildRequires:  pkgconfig(libavformat) >= 55.48.100
BuildRequires:  pkgconfig(libraw)
BuildRequires:  pkgconfig(libswscale) >= 2.6.100
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(vapigen)
# For umfpack
BuildRequires:  suitesparse-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# since version 0.3.5, we no longer provide an orig-addon package, as ffmpeg/libav
# exists in Tumbleweed and we use it to build
Provides:       %{_name}-0_3-orig-addon = %{version}
Obsoletes:      %{_name}-0_3-orig-addon < 0.3.5

%description
GEGL provides infrastructure to do demand based cached non destructive
image editing on larger than RAM buffers. Through babl it provides
support for a wide range of color models and pixel storage formats for
input and output.

%package -n %{_name}-0_3
Summary:        Generic Graphics Library
Group:          System/Libraries
Recommends:     %{_name}-0_3-lang

%description -n %{_name}-0_3
GEGL provides infrastructure to do demand based cached non destructive
image editing on larger than RAM buffers. Through babl it provides
support for a wide range of color models and pixel storage formats for
input and output.

%package -n libgegl-0_3-0
Summary:        Generic Graphics Library
Group:          System/Libraries
# The plugins are required for the lib to be usable
Requires:       %{_name}-0_3 >= %{version}

%description -n libgegl-0_3-0
GEGL provides infrastructure to do demand based cached non destructive
image editing on larger than RAM buffers. Through babl it provides
support for a wide range of color models and pixel storage formats for
input and output.

%package devel
Summary:        Generic Graphics Library
Group:          System/Libraries
Requires:       libgegl-0_3-0 = %{version}

%description devel
GEGL provides infratructure to do demand based cached non destructive
image editing on larger than RAM buffers. Through babl it provides
support for a wide range of color models and pixel storage formats for
input and output.

%package doc
Summary:        Generic Graphics Library
Group:          System/Libraries
Requires:       libgegl-0_3-0 = %{version}

%description doc
GEGL provides infrastructure to do demand based cached non destructive
image editing on larger than RAM buffers. Through babl it provides
support for a wide range of color models and pixel storage formats for
input and output.

%lang_package -n %{_name}-0_3

%prep
%setup -q -n %{_name}-%{version}

%build
./autogen.sh
export RPM_OPT_FLAGS="%{optflags} -fno-strict-aliasing"
## Not passing --enable-workshop=yes\ as it breaks the build atm
%configure\
	--disable-static --disable-silent-rules
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
# remove example programs
for example in \
    gegl-tester; do
    rm %{buildroot}%{_bindir}/$example
done
find %{buildroot} -type f -name "*.la" -delete -print
# move some files out of the way to not conflict with gegl 0.2
mv %{buildroot}%{_bindir}/gegl %{buildroot}%{_bindir}/gegl-0.3
mv %{buildroot}%{_bindir}/gegl-imgcmp %{buildroot}%{_bindir}/gegl-imgcmp-0.3
mv %{buildroot}%{_datadir}/gtk-doc/html/gegl/ %{buildroot}%{_datadir}/gtk-doc/html/gegl-0.3/
%find_lang %{_name}-0.3 %{?no_lang_C}

%post -n gegl-0_3 -p /sbin/ldconfig
%post -n libgegl-0_3-0 -p /sbin/ldconfig

%postun -n gegl-0_3 -p /sbin/ldconfig
%postun -n libgegl-0_3-0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/gegl-0.3
%{_bindir}/gegl-imgcmp-0.3

%files -n %{_name}-0_3
%defattr(-,root,root)
%dir %{_libdir}/gegl-0.3/
%{_libdir}/gegl-0.3/*.so
# libgegl-sc-0.3.so is a support library for the seamless-clone module
%{_libdir}/libgegl-sc-0.3.so
%{_libdir}/libgegl-npd-0.3.so
%{_libdir}/gegl-0.3/grey2.json

%files -n libgegl-0_3-0
%defattr(-,root,root)
%doc AUTHORS COPYING COPYING.LESSER NEWS
%{_libdir}/libgegl-0.3.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/gegl-0.3/
%{_libdir}/libgegl-0.3.so
%{_libdir}/pkgconfig/gegl-0.3.pc
%{_libdir}/pkgconfig/gegl-sc-0.3.pc

%files doc
%defattr(-,root,root)
%doc %{_datadir}/gtk-doc/html/gegl-0.3/

%files -n %{_name}-0_3-lang -f %{_name}-0.3.lang
%defattr(-,root,root)

%changelog
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 0.3.6:
  + gegl-binary: make ops chain pass to mrg ui.
  + git-binary: rename mrg-ui to ui.
  + gegl-binary: factor out commandline to chain builder in a
    function.
  + gegl-binary: assume gegl: prefix for unprefixed ops.
  + gegl-binary: permit specifying pads on commandline.
  + gegl-binary: document property assignment.
  + bin: Fix compilation error in previous commit.
  + Updated Polish translation.
  + gegl-binary: support specifying more complex DAGs than linear
    chains from commandline.
  + tests: Re-connecting connected nodes should not cause
    invalidation.
  + tests: Sources shouldn't be invalidated when connecting &
    disconnecting.
  + Updated Slovenian translation.
  + gegl-binary: add scroll-wheel based zoom.
  + gegl-binary: center scroll-wheel zoom on cursor.
  + gegl-binary: refresh mrg scroll api.
  + bin/gegl: add unsharp-mask as an op.
  + bin/gegl handle GeglColor and enums.
  + Updated Slovenian translation.
  + tests: remove webm part of ff-save smoketest.
  + release 0.3.6.
* Fri Mar 11 2016 dimstar@opensuse.org
- Update to version 0.3.5~20160303:
  + Rename insta-curve and insta-filter to retro-curve and
    retro-filter.
  + Move retro-curve/-filter out of workshop.
  + Remove retro look filter presets.
  + Updated POTFILES.in.
  + GeglNode: Clean up.
  + Short circuit gegl_node_connect_from if the nodes are already
    connected.
* Wed Mar  2 2016 dimstar@opensuse.org
- Update to version 0.3.5~20160229:
  + operations/workshop/insta-curve: Fix crash while building.
  + operations/core/nop: Remove a needless and wrong cast.
  + tiff: Fix inversion between case and return values.
  + point-coposer3: skip some multi-threading for opaque buffers.
  + video-degradation: add opencl support.
  + gegl: set properties on = arguments.
  + Updated translations.
- Use _service, as we require a git snapshot for GNOME Photos. It
  is not clear when the next release will happen.
- Call autogen.sh, as the git-checkout is not bootstrapped.
- Drop gegl-unstable-0_3-orig-addon subpackage: this was purely
  split so that 3rd party OBS instances could build gegl against
  ffmpeg/libav. As openSUSE ships ffmpeg by now, this is no longer
  required. Accordingly, provide and obsolete
  gegl-unstable-0_3-orig-addon.
- Remove traces of ?BUILD_ORIG / ?BUILD_ORIG_ADDON.
- Replace (prior conditional, now unconditional) ffmpeg-devel
  BuildRequires with pkgconfig(libavcodec), pkgconfig(libavformat)
  and pkgconfig(libswscale): follow what configure is looking for.
- Drop babl-devel, glib2-devel, glibc-devel and pcre-devel Requires
  from the -devel subpackage: they are auto-detected.
* Fri Feb 12 2016 zaitor@opensuse.org
- Replace libopenraw-devel for pkgconfig(libraw) BuildRequires,
  really build libraw support, as configure was not satisfied with
  libopenraw-devel.
- Add pkgconfig(gexiv2), pkgconfig(libtiff-4), pkgconfig(libv4l2),
  pkgconfig(libwebp) and pkgconfig(vapigen) BuildRequires,
  configure looks for these optional dependencies.
* Tue Dec 15 2015 zaitor@opensuse.org
- Add missing post/postun handling for gegl-0_3.
* Thu Nov 26 2015 zaitor@opensuse.org
- Update to version 0.3.4:
  + build: do not install examples in path
  + ff-save fully store all in-flight codec contexts before closing
    files
  + ff-load improvements to seeking accuracy
  + transform: make fast paths skip pixel format conversions
- Changes from version 0.3.2:
  + Operations:
  - new operations: libraw based raw loading op, tiff-save and
    tif-load, maze, sepia
  - ff-load and ff-save revived, with support from thegrid.io
  - apply-lens uses less memory, higher precision computation
  - disable automatic threading on many ops where it fails
  - force more operations to prefer operating on linear RGB data
    for more accurate/physical processing
  + Buffer: implement abyss paremeter on gegl_buffer_copy and
    gegl_buffer_blit
  + Added start of a microraptor gui based image viewer/non
    destructive editor.
  + Optimizations to scaled blitting (speeds up most GEGL UIs a
    bit).
- Change %%define debug_package_requires libgegl-0_2-0 to
  %%define debug_package_requires libgegl-0_3-0.
- Stop removing no longer existing examples.
* Wed Jun 10 2015 zaitor@opensuse.org
- Update to version 0.3.0:
  + Improvements to thread safety and parallelism.
  + Lower overhead graph travesal due from rewrite of visitors.
  + OpenCL support now enabled by default when detected.
  + Experimental multithreading, enable by setting
    GEGL_THREADS=<number of threads> in the environment.
  + Experimental mipmap rendering, which permits transparent
    rendering of previews on smaller sized versions, enable by
    setting GEGL_MIPMAP_RENDERING=true in the environment.
  + Buffer: New default tile backend, doing disk writes in a
    separate thread.
- Temp stop passing --enable-workshop=yes to configure as it break
  the build atm.
* Sun May  3 2015 stefan.bruens@rwth-aachen.de
- move libgegl-sc-0.3.so to the plugin package, it is a support
  library for the seamless-clone plugin
* Wed Apr 22 2015 dimstar@opensuse.org
- Be more accurate with the BuildRequire versions.
* Wed Feb 18 2015 dimstar@opensuse.org
- Update to version 0.3.0~20150218:
  + configure: bump babl requirement to 0.1.12
  + Updated Basque language
  + Updated Basque language
  + fix: undefined string comparison in gegl:load operation
  + Change sRGB Y values to match sRGB built-in profiles
  + operations: string fixes/changes in gegl:distance-transform
  + Bug 698380 - Add gegl_module_error_message() which sets and displays...
  + Fix errors in Catalan translation
  + Updated Polish translation
  + operations/workshop/external: distribute generated header files
* Wed Feb 18 2015 dimstar@opensuse.org
- Split to gegl-unstable, following git master branch (based on
  _service). GNOME 3.16 requires a newer version of gegl, but many
  other packages are not ready for that (e.g. gimp).
* Sat Oct 25 2014 i@marguerite.su
- fix build for factory
  * add patch: gegl-UF_long.patch
  * newer suitesparse abandoned UF_long in favor for SuiteSparse_long
- fix build for graphics repo
  * ugly fix, multiple provides of gd by gd and gd-tools from libgd2
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Fri May 18 2012 dimstar@opensuse.org
- Add gegl-ruby19.patch: Fix build with ruby 1.9.
- Add liberation-fonts: the documentation references bitstream
  vera sans font, so we need to provide it for the build.
* Tue Apr  3 2012 vuntz@opensuse.org
- Update to version 0.2.0:
  + OpenCL support
  + Build improvements.
  + High level API to apply ops directly to buffers with arguments.
  + Final bits of translation infrastructure.
  + Invalidate regions when disconnecting input pads.
  + Operations:
  - New operation: global-matting
  - Allow transform core to do perspective transforms.
  - Added string based key/value pairs to operations.
  - Added arguments for dealing with scaled down preview
    rendering.
  + Added human interaction ranges and non-linear mapping to
    properties.
  + Buffer:
  - Removed broken lanczos sampler.
  - Add gegl_buffer_set_color and gegl_buffer_set_pattern
  - Added ability to drop cached tiles.
  - Added API for handling abyss policy (not implemented yet)
  - Avoid iterating global tile cache when flushing/destroying
    buffers that have no tiles in the cache.
- Add intltool BuildRequires: new dependency upstream, for
  translations.
- Add lensfun-devel BuildRequires to build with lensfun support.
- Add libexiv2-devel BuildRequires to build with libexiv2 support.
- Add libjasper-devel BuildRequires to build with Jasper support.
- Add libspiro-devel BuildRequires to build with SPIRO support.
- Add suitesparse-devel BuildRequires to build with UMFPACK
  support.
- Uncomment ruby BuildRequires: it was commented out because a file
  was missing in a earlier tarball.
- Rename subpackages from gegl-0_1/libgegl-0_1-0 to
  gegl-0_2/libgegl-0_2-0 following the upstream soname change.
- Create a gegl-0_2-lang subpackage for new translations.
* Wed Jan 11 2012 vuntz@opensuse.org
- Add gegl-lua52.patch: fix build with lua 5.2, while still being
  compatible with lua 5.1.
* Sun Nov 27 2011 dimstar@opensuse.org
- Update to version 0.1.8:
  + New operations: spread, vignette, map-relative,
    noise-reduction, plasma, fractal-trace, exr-save, lens-correct,
    emboss, cubism, ripple, color-to-alpha, color-rotate,
    red-eye-removal, convolution-matrix, deinterlace,
    polar-coordinates, lens-distortion, pixelise.
  + Split GeglView GTK Widget into separate utility library
  + build/test improvements.
  + Buffer:
  - Added lohalo resampler, API and infrastructure for doing non
    affine resamplings.
- Clean spec-file using spec-cleaner.
- Drop docs-build-fix.diff: fixed upstream.
* Mon Jun 20 2011 jw@novell.com
- update to 0.1.6 (see NEWS)
  • New operations: max-rgb, pixelise, motion blur.
  • Fixed a bugs in matting-levin that made GEGL halt due to errors
  detected by babl sanity code, this made 0.1.4 be unusable if you had
  all dependendency when building.
  • build/test improvements.
  • Buffer:
    Added API to use external tile backends, allowing to plug-in alien
    tilebackends, for GIMP/Krita/OSM or similar.
- remove upstreamed patches bgo609706 bgo610680 (thanks, Vincent)
* Thu May  5 2011 dimstar@opensuse.org
- BuildRequire graphviz-gd instead of graphviz: we do require png
  capabilities, which are split out of the main package.
  Theoretically, we should require graphviz-devel, but this package
  also does not drag in -gd.
* Mon Feb 22 2010 vuntz@opensuse.org
- Add gegl-fix-overflow.patch to fix overflow found by gcc 4.5.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 0.1.2:
  + GeglLookup, configurable floating point lookup tables for lazy
    computation.
  + Use GFileIOStream in GeglTileBackendFile.
  + Optimizations: in-place processing for point filters/composers,
    SIMD version of gegl:opacity, avoid making unneccesary
    sub-buffers, removed some  manual instrumentation from critical
    paths, improved speed of samplers.
  + Added xml composition/reference image based regression tests.
  + Added performance tracking framework.
  + Syntactic sugar using varargs for constructing gegl graphs from
    C.
  + Build fixes on cygwin.
  + Gegl# fixes.
  + Initial, but unstable code towards multithreading.
  + Improvements to lua op in workshop.
  + Added new resamplers upsize, upsharp, upsmooth, downsize,
    downsharp and downsmooth.
  + Removed gegl:tonemap and gegl:normal ops.
- Drop gegl-new-babl.patch: fixed upstream.
- Add gegl-fix-build.patch: remove printf that breaks build because
  of missing include.
- Rename package from gegl-0_0 and libgegl-0_0-0 to gegl-0_1 and
  libgegl-0_1-0 following soname bump.
* Thu Jan 28 2010 vuntz@opensuse.org
- Add gegl-new-babl.patch to fix build with babl 0.1.2.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 0.1.0:
  + Renamed gegl:load-buffer to gegl:buffer-source and
    gegl:save-buffer to gegl:buffer-sink (but the old names still
    work)
  + Represent colors using doubles instead of floats (this change
    is independent from internal processing)
  + Removed the GTK+ UI parts of the gegl binary and turned gegl
    into a pure command line tool (which can still visualize stuff
    with help help the SDL based display operation)
  + Consider {x=G_MININT/2, y=G_MININT/2, width=G_MAXINT,
    height=G_MAXINT} as the only valid region wichin processing
    may occur. Processing outside of this region is undefined
    behaviour.
  + Added support for storing allocation stack traces for
    GeglBuffers so that debuging buffer leaks becomes much easier
  + Made small changes and cleanups of the public API, e.g.
  - Removed gegl_node_adapt_child()
  - Made GeglConfig an explicit object
  - Removed most of the ifdeffed stuff to mask away internal
    structures
  - Added gegl_rectangle_infinite_plane() and
    gegl_rectangle_is_infinite_plane()
  + Added new sampler GeglSamplerSharp
  + Added format property go gegl:buffer-sink
  + Cleaned up and made gegl:introspect work again
  + Add a bunch of test cases using the automake test sytem (make
    check) and also port buffer tests to automake
  + General cleanups, bug fixes, increased robustness and improved
    documentation
- Drop gegl-babl_api_change.patch: fixed upstream.
- Temporarly remove ruby BuildRequires as the build is broken when
  it's there right now.
* Thu Jun 11 2009 vuntz@novell.com
- Add gegl-babl_api_change.patch to make gegl build with babl
  0.1.0. Patch taken from Fedora.
- Remove autoreconf call.
- Do not make gegl0_0 explicitly Requires libbabl-0_0-0.
* Wed Dec 31 2008 hfiguiere@suse.de
- Update to 0.0.22
  * GeglOperation
  - operation names are now prefixed, the ops in GEGL use 'gegl:' as prefix.
  - gegl:opacity - combine value and aux mask input when both are available.
  - gegl:src-in - deal correctly with extens.
  - gegl:path - new op covering the stroke/fill needs of SVG.
  - deprecated gegl:shift, the affine familiy of operations now
    uses the same fast code paths for integer translations.
  * GeglBuffer
  - Profiling motivated speed ups in data reading/writing.
  - Remove left-over swapfiles from dead processes at startup.
  * GeglNode
  - made gegl_node_add_child and gegl_node_remove_child public API. (bgo#507298)
  * GeglPath: Vector path representation infrastructure,
- Remove gegl-64bit-warning.diff
* Mon Oct  6 2008 hfiguiere@suse.de
- Update to 0.0.20
  * libopenraw support
  * Linear buffer support, amongst other things enabling GeglBuffer API access
    to external linear buffers in memory.
  * Reworked samplers using a shared caching neighbourhood infrastructure.
  * YAFR - a new resampler contributed by Nicolas Robidoux.
  * Marked user visible strings for translation.
  * Added a fill operation (might be a bit fragile) that allows rendering
    SVG like paths backed by a GeglVector.
- Remove gegl-strict-compile-fix.diff
- Added gegl-64bit-warning.diff
  * Address a fatal warning on 64bits
* Wed Oct  1 2008 hfiguiere@suse.de
- Add patch gegl-strict-compile-fix.diff:
  * Fix header for stricter compilation
- enable workshop at compile time
* Mon Sep 29 2008 sbrabec@suse.cz
- Fixed dependencies.
- Fixed permissions of documentation.
* Mon Jul 21 2008 sbrabec@suse.cz
- New SuSE package.
